BOOST_PP_REMOVE_PARENS

The BOOST_PP_REMOVE_PARENS macro removes the beginning parenthesis, if it exists, from the input data and expands to the result

#### Usage

BOOST_PP_REMOVE_PARENS(param) (v)

#### Arguments

#### param The input data.

#### Remarks

If the input begins with a parenthesis, with any data within that parenthesis, the macro removes the parenthesis and expands to the result. If the input does not begin with a parenthesis the macro expands to the input.

#### See Also

- BOOST_PP_IS_BEGIN_PARENS

#### Requirements

Header: <boost/preprocessor/punctuation/remove_parens.hpp>

#### Sample Code

    #include <boost/preprocessor/punctuation/remove_parens.hpp>

    #define DATA data
    #define DATAP ( data ) more_data

    BOOST_PP_REMOVE_PARENS(DATA)     // expands to 'data'
    BOOST_PP_REMOVE_PARENS(DATAP)    // expands to 'data more_data'

© Copyright Edward Diener 2014

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)